/*
 *			Remote LSA
 *
 *			Copyright (c) 1998 LeCroy Corporation
 *			
 *			Written By: Ricardo Palacio
 *
 *			April, 1998
 *
 *
 */



/* 
 * $Header: /Test Framework 3/900040 Software Apps/LSA1000 GS/Interface/gpib_drv.c 1     6/22/98 1:24p Ricardop $
 * $Log: /Test Framework 3/900040 Software Apps/LSA1000 GS/Interface/gpib_drv.c $
 * 
 * 1     6/22/98 1:24p Ricardop
 * 
 */


#include <windows.h>
#include <stdio.h>
#include <time.h>
#include <gpib_drv.h>
#include <gpib.h>


static int				sTimeout = 15;
static int 				sConnectedFlag = FALSE;
static int 				sBrd_Descriptor = 0;
static int 				sDev_Descriptor = 0;
#define CMD_BUF_LEN		8192
static char 			sCommandBuffer[CMD_BUF_LEN];






int GPIB_Connect(int gpib_addr)
{

	char tmpStr[512], *strPtr1, *strPtr2;
	int dev_desc, result;
	short found;
	
	
	if (sConnectedFlag==TRUE)
		return -1;
	
	/*----------------------------------------------------------------------------------*/
	/* Get the board descriptor for the local board 
		There's only one board descriptor for each bd.
		and calling ibfind many times just returns the same
		bd. descriptor.
	*/
	
	sBrd_Descriptor = ibfind("GPIB0");
	if (sBrd_Descriptor < 0)
		return -1;
	result = ibconfig(sBrd_Descriptor, IbcAUTOPOLL, 0);
	if (result&ERR)
		return -2;
	result = ibtmo (sBrd_Descriptor, T10s);
	if (result&ERR)
		return -3;
	
	/*--Try to open a connection to the instrument--------------------------------------*/
	sDev_Descriptor = ibdev (0, gpib_addr, NO_SAD, T3s, 1, 0);
	if (sDev_Descriptor < 0)
		return -4;

	// check for listener
	ibln (sDev_Descriptor, gpib_addr, NO_SAD, &found);
	if (!found)
	{
		ibonl(sDev_Descriptor, FALSE); 
		return -5;
	}

	sConnectedFlag = TRUE;

	return 0;
}




/* disconnectFromScope: disconnect from a network device */
int GPIB_Disconnect(void)
{
	
	if (sConnectedFlag != TRUE)
		return -1;
    
	ibonl(sDev_Descriptor, FALSE); 
	
	sConnectedFlag = FALSE;
	
	return 0;
}






int GPIB_WriteDevice(char *buf, int len, BOOL eoi_flag)
{
	int result;
	
	
	if (sConnectedFlag != TRUE)
		return -1;
		
	if (len < CMD_BUF_LEN)
		strcpy(sCommandBuffer, buf);
	
	
	result = ibwrt (sDev_Descriptor, buf, len);
	if (result&ERR)
		return -1;
	
	if (len != ibcntl)
		return -1;
		
	
	return 0;
}





int GPIB_ClearDevice(void)
{

	if (sConnectedFlag != TRUE)
		return -1;
	
	ibclr(sDev_Descriptor);
	
	return 0;
}







int GPIB_ReadDevice(char *buf, int len, int *recv_count)
{
	int result;
	
	
	if (sConnectedFlag != TRUE)
		return -1;
	
	
	result = ibrd (sDev_Descriptor, buf, len);
	if (result&ERR)
		return -1;
		
	buf[ibcntl] = 0;
	*recv_count = ibcntl;
	
	return 0;
}







int GPIB_SetTimeout(int seconds)
{

	sTimeout = seconds;
	return 0;
}
