/*
 *			Remote LSA
 *
 *			Copyright (c) 1998 LeCroy Corporation
 *			
 *			Written By: Ricardo Palacio
 *
 *			April, 1998
 *
 *
 */





/* 
 * $Header: /Test Framework 3/900040 Software Apps/LSA1000 GS/Interface/interface.c 2     6/22/98 1:24p Ricardop $
 * $Log: /Test Framework 3/900040 Software Apps/LSA1000 GS/Interface/interface.c $
 * 
 * 2     6/22/98 1:24p Ricardop
 * added gpib driver
 * 
 * 1     4/27/98 4:53p Ricardop
 * Initial check-in
 * 
 */



#include <ansi_c.h>
#include <tcp_drv.h>
#include <gpib_drv.h>
#include <windows.h>
#include <formatio.h>
#include <interface.h>


typedef enum
{
	UNDEFINED = -1,
	TCPIP_DEVICE = 1,
	GPIB_DEVICE
}INTERFACE_CLASS;



static INTERFACE_CLASS 		sConnectionType = UNDEFINED;




int (*FN_Disconnect) 	(void) = NULL;
int (*FN_WriteDevice)	(char *buf, int len, BOOL eoi_flag) = NULL;
int (*FN_ReadDevice)	(char *buf, int len, int *recv_count) = NULL;
int (*FN_SetTimeout)	(int seconds) = NULL;

static sInterfaceSpy = FALSE;


//"GPIB:1", "GPIB:2", or "TCPIP:172.28.11.26"
int IM_MakeConnection(char *address)
{
	char tmpStr[512];
	char *strPtr;
	int gpib_addr;
	
	
	if (sConnectionType != UNDEFINED)
		IM_Disconnect();
	
	
	StringUpperCase (address);

	if (strstr(address, "IP:"))
	{
		strPtr = strchr(address, ':');
		if (strPtr)
			++strPtr;
		if (TCP_Connect(strPtr))
			return -1;
		sConnectionType = TCPIP_DEVICE;
		FN_Disconnect = TCP_Disconnect;
		FN_WriteDevice = TCP_WriteDevice;
		FN_ReadDevice = TCP_ReadDevice;
		FN_SetTimeout = TCP_SetTimeout;
	}
	else if (strstr(address, "GPIB:"))
	{
		strPtr = strchr(address, ':');
		if (strPtr)
			++strPtr;
		
		gpib_addr = atoi(strPtr);
		if (GPIB_Connect(gpib_addr))
			return -1;	
		sConnectionType = GPIB_DEVICE;
		FN_Disconnect = GPIB_Disconnect;
		FN_WriteDevice = GPIB_WriteDevice;
		FN_ReadDevice = GPIB_ReadDevice;
		FN_SetTimeout = GPIB_SetTimeout;
	}
	else if (strstr(address, "DNS:"))
	{
		return -1;
	}
	else
	{
		sprintf(tmpStr, "Unrecognized address format, %s", address);
		MessageBox(0, tmpStr, "ERROR", MB_OK);
		return -1;
	}

	return 0;
}





int IM_Disconnect(void)
{

	if (FN_Disconnect)
		FN_Disconnect();
	
	FN_Disconnect = NULL;
	FN_WriteDevice = NULL;
	FN_ReadDevice = NULL;
	FN_SetTimeout = NULL;
	sConnectionType = UNDEFINED;
	
	return 0;
}



int IM_WriteDevice(char *string)
{

	if (sInterfaceSpy)
	{
		printf("Write:\n");
		printf(string);
		printf("\n");
	}
	
	if (FN_WriteDevice)
		return FN_WriteDevice(string, strlen(string), TRUE);
	
	return -1;
}





int IM_ReadDevice(char *buffer, int buf_size)
{
	int recv_count, err;
	
	if (FN_ReadDevice==NULL)
		return -1;
		
	err = FN_ReadDevice(buffer, buf_size, &recv_count);
	
	if ((sInterfaceSpy)&&(recv_count < 128))
	{
		printf("Read:\n");
		printf(buffer);
	}
	
	return err;
}





int IM_QueryDevice(char *cmd, char *rsp_buf, int buf_size)
{

	if (IM_WriteDevice(cmd))
		return -1;
	if (IM_ReadDevice(rsp_buf, buf_size))
		return -1;
	
	return 0;
}





int IM_SetTimeout(int seconds)
{

	if (FN_SetTimeout)
		return FN_SetTimeout(seconds);

	return -1;
}






int IM_SetSpy(BOOL state)
{
	sInterfaceSpy = state;
	return 0;
}
