/*
 *			Remote LSA
 *
 *			Copyright (c) 1998 LeCroy Corporation
 *			
 *			Written By: Ricardo Palacio
 *
 *			April, 1998
 *
 *
 */

#define MAX_TRACE_DISPLAYED		5
#define MAX_TRACE_COUNT			9
#define MAX_TRIG_COUNT			8		// 7 sources - C1, C2, C3, C4, Ext, Ext10, Line
#define NO_VALUE				~0
#define ON						1
#define OFF						0


#ifndef ULONG
	#define ULONG	unsigned long
#endif

#ifndef POSITIVE
	#define POSITIVE			1
#endif

#ifndef NEGATIVE
	#define NEGATIVE			0
#endif


typedef enum
{
	CURS_NONE = -1,
	CURS_TRIGGER = 1,
	CURS_MEASURE
} eCURSOR_TYPE;


typedef enum 
{
	CHANNEL_1 = 1,
	CHANNEL_2,
	CHANNEL_3,
	CHANNEL_4,
	MAX_CHANNEL_COUNT
} DSO_CHANNEL;



typedef enum 
{
	TRACE_1 = 1, 
	TRACE_2, 
	TRACE_3, 
	TRACE_4,
	TRACE_5, 
	TRACE_6, 
	TRACE_7, 
	TRACE_8
} TRACE_INDEX;


typedef enum 
{
	TRIG_1 = 1, 
	TRIG_2, 
	TRIG_3, 
	TRIG_4,
	TRIG_5, 
	TRIG_6, 
	TRIG_7
} TRIG_INDEX;



typedef enum 
{
	TRACE_ID_C1 = 1,
	TRACE_ID_C2,
	TRACE_ID_C3,
	TRACE_ID_C4,
	TRACE_ID_TA,
	TRACE_ID_TB,
	TRACE_ID_TC,
	TRACE_ID_TD
} TRACE_ID;


typedef enum 
{
	TRIG_ID_C1 = 1,
	TRIG_ID_C2,
	TRIG_ID_C3,
	TRIG_ID_C4,
	TRIG_ID_EXT,
	TRIG_ID_EXT10,
	TRIG_ID_LINE
} TRIG_ID;


typedef enum 
{
	TRIG_TYPE_EDGE = 1,
	TRIG_TYPE_GLITCH,
	TRIG_TYPE_INTERVAL,
	TRIG_TYPE_TV,
	TRIG_TYPE_QUALIFIED,
	TRIG_TYPE_DROPOUT,
	TRIG_TYPE_PATTERN
} TRIG_TYPE_ID;


typedef struct 
{
	int 			cxBox_Label;
	int				cxBorder;
	int 			cxTDIV_Message;
	int 			cxVDIV_Message;
	BOOL 			bDisplayed;
} INFO_BOX_CONTROLS;


typedef struct 
{
	int 		cxVDIV;
	int 		cxCoupling;
	int 		cxOffset;
	int 		cxFind;
	int			cxChan_ON_OFF[MAX_CHANNEL_COUNT];
	int 		cxChan_Select[MAX_CHANNEL_COUNT];
} CHANNEL_CONTROLS;



typedef struct 
{
	int 		cxTDIV;
	int 		cxDelay;
	int 		cxDelay_Slide;
	int 		cxStop;
	int 		cxAuto;
	int 		cxNorm;
	int 		cxSngl;
	int 		cxSlope;
	int 		cxCoupling;
	int 		cxSource;
	int 		cxTrg_Cursor;
	int 		cxSample_Size;
} TIMEBASE_CONTROLS;


typedef struct 
{
	int 		cxType;
	int 		cxSource;
	int 		cxSlope;
	int 		cxCoupling;
	int			cxGlitch_At_End_Of;
	int			cxGlitch_Smaller_Equal_Than_Switch;
	int			cxGlitch_Smaller_Equal_Than_Value;
	int			cxGlitch_Greater_Equal_Than_Switch;
	int			cxGlitch_Greater_Equal_Than_Value;
} TRIGGER_CONTROLS;



typedef struct 
{
	int 		cxGrid_Enable;
	int 		cxMeasure_Cursor;
	int 		cxPersistence;
	int 		cxDual_Screen;
	int			cxScope_Display;
} UTILITY_CONTROLS;


typedef struct 
{
	int 		cxTrace[MAX_CHANNEL_COUNT];
	int 		cxTrace_Select[MAX_CHANNEL_COUNT];
	int 		cxOffset;
	int 		cxPosition;
	int 		cxFunction_Button;
	int 		cxVMAG;
	int 		cxHMAG;
	int 		cxMAG_Reset;
} ZOOM_MATH_CONTROLS;


typedef struct 
{
	int 		cxPath;
	int 		cxFilename;
	int 		cxIndex;
	int 		cxLed;
	int 		cxNo_Of_Acquisitions;
	int 		cxStop;
	int 		cxStart_Acquisition;
	int         cxDatalogger;
} DATALOGGER_CONTROLS;



typedef struct 
{
	int 		cxMeasure_Text;
	int 		cxTrig_Mode_Text;
	int 		cxUpdate_Rate_Text;
	int 		cxCommand_Box;
	int 		cxReply_Box;
	int 		cxRun_Message;
	int 		cxSample_Rate_Text;
	int 		cxTrg_Level_Text;
	int 		cxError_Message;
} MISC_CONTROLS;




typedef struct 
{
	int 				hNewConnection;
	int 				hMainPanel;
	int 				hTimebasePanel;
	int 				hChannelPanel;
	int					hTriggerPanel;
	int 				hMathPanel;
	int 				hUtilityPanel;
	int 				hCommandPanel;
	int 				hDataloggerPanel;
	int 				hTabControl;
	int 				hPlotHandle[MAX_TRACE_COUNT];
	int 				cxScreen1;
	int 				cxScreen2;
	int 				cxActive_Cursor;
	int 				cxActive_Cursor_Panel;
	INFO_BOX_CONTROLS	Info_Box[MAX_TRACE_DISPLAYED];
	CHANNEL_CONTROLS	Channel_Controls;
	TIMEBASE_CONTROLS	Timebase_Controls;
	TRIGGER_CONTROLS	Trigger_Controls;
	UTILITY_CONTROLS	Utility_Controls;
	ZOOM_MATH_CONTROLS	Zoom_Math_Controls;
	DATALOGGER_CONTROLS Datalogger_Controls;
	MISC_CONTROLS		Misc_Controls;
} PANEL_INFO;





typedef struct 
{
	TRACE_ID	Trace_ID;
	BOOL		bTrace_ON;
	char	 	*ptrRawData;
	ULONG		ulTrace_Color;
	ULONG		ulTrace_Size;
	char 		szTrace_Name[256];
	int 		iInfoBox_Index;
	double 		dOffset;
	double		dVDIV;
	double 		dAttenuation;
	double 		dZoom_Offset;
	double 		dZoom_Position;
	double 		dZoom_HMAG;
	double 		dZoom_VMAG;
	char		szChan_Coupling[32];
} TRACE_INFO;



typedef struct 
{
	TRIG_ID			Trig_ID;
	TRIG_TYPE_ID	Trig_Type_ID;
	char			szTrig_Type[32];
	char 			szTrig_Mode[32];
	int 			iTrig_Source;
	char 			szTrig_Source[32];
	double 			dTrig_Level;
	BOOL 			bTrig_Slope;
	char 			szTrig_Coupling[32];
	char			szTrig_Holdoff_Type[32];
	ULONG			ulTrig_Holdoff_Event;
	double			dTrig_Holdoff_Time;
	char			szTrig_Glitch_Pulse_Type[32];
	double			dTrig_Glitch_Pulse_Smaller;
	double			dTrig_Glitch_Pulse_Larger;
} TRIG_INFO;




typedef struct 
{
	TRACE_INFO		Trace[MAX_TRACE_COUNT];
	TRIG_INFO		Trig[MAX_TRIG_COUNT];
	char 			szTrig_Mode[32];
	double 			dTDIV;
	char			szTrig_Type[32];
	double 			dTrig_Level;
	double 			dTrig_Delay;
	BOOL 			bTrig_Slope;
	ULONG			ulMemory_Size;
	char  			szMemory_Size[32];
	int 			iTrig_Source;
	char 			szTrig_Source[32];
	char 			szTrig_Coupling[32];
	int 			iMax_Channels;
	int 			iSelected_Channel;
	int 			iSelected_Math_Trace;
	int 			iNum_Screen;
	BOOL 			bPersistence;
	BOOL			bScope_Display;
	char 			*ptrReadBuffer;
	BOOL			bToolsEnabled;
	BOOL			bMeasureCursorOn;
} DSO_INFO;



extern DSO_INFO		gDSO_Info;
extern PANEL_INFO	gPanel_Info;



// display/hide execute message
#define mSetRunMessage(A) 	SetCtrlAttribute (gPanel_Info.hCommandPanel, \
											gPanel_Info.Misc_Controls.cxRun_Message, \
											ATTR_VISIBLE, A); \
							ProcessDrawEvents();



