/*
 *			Remote LSA
 *
 *			Copyright (c) 1998 LeCroy Corporation
 *			
 *			Written By: Ricardo Palacio
 *
 *			April, 1998
 *
 *
 */


/* 
 * $Header: /Test Framework 3/900040 Software Apps/LSA1000 GS/Net LSA/panel_cb.c 6     7/16/98 4:22p Ricardop $
 * $Log: /Test Framework 3/900040 Software Apps/LSA1000 GS/Net LSA/panel_cb.c $
 * 
 * 10     	09/24/01 Peter Wilhelm
 * 			Traces ON /OFF extended to scope display
 *
 * 9     	04/21/01 Peter Wilhelm
 * 			Zoom & Math Reset button changed. Now it executes the same function as the RESET on the scope does
 *
 * 8     	02/05/01 Peter Wilhelm
 * 			Enbabled Trigger Coupling for use with LT / WP scopes
 *
 * 
 * 7     	12/18/00 Peter Wilhelm
 * 			Enbabled SetVoltsPerDiv for use with LT / WP scopes
 *			Enbabled SetChanCoupling for use with LT / WP scopes
 * 
 * 6     7/16/98 4:22p Ricardop
 * fixed trigger cursor update problem
 * 
 * 5     6/25/98 11:13a Ricardop
 * Removed Test tools
 * 
 * 3     6/22/98 1:26p Ricardop
 * Removed local time-out setting.  The default time-out is set to 15 sec.
 * 
 * 2     5/05/98 10:17a Ricardop
 * 
 * 1     4/27/98 4:53p Ricardop
 * Initial check-in
 * 
 */

#include <ansi_c.h>
#include <utility.h>
#include <userint.h>
#include <toolbox.h>
#include <analysis.h>
#include <formatio.h>
#include <toolbox.h>
#include <inifile.h>

// LeCroy Libs.
#include <interface.h>
#include <dsopanel.h>
#include <global_info.h>
#include <update_panel.h>
#include <update_struct.h>
#include <str_utils.h>
#include <update_plot.h>

#if defined ENABLE_TEST_TOOLS
	#include <sig_utils.h>
#endif



static char buffer[1000000];
static int no_of_acquisitions;


int CVICALLBACK SetPersistence (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &gDSO_Info.bPersistence);
			break;
	}
	return 0;
}




int CVICALLBACK ShowGridCallback (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	int val;
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			if (val) 
			{
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, ATTR_XGRID_VISIBLE, TRUE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, ATTR_YGRID_VISIBLE, TRUE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, ATTR_XGRID_VISIBLE, TRUE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, ATTR_YGRID_VISIBLE, TRUE);
			}
			else 
			{
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, ATTR_XGRID_VISIBLE, FALSE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, ATTR_YGRID_VISIBLE, FALSE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, ATTR_XGRID_VISIBLE, FALSE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, ATTR_YGRID_VISIBLE, FALSE);
			}
			break;
	}
	return 0;
}



int CVICALLBACK SetNumScreen (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	int val;
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			if (val) 
			{
				gDSO_Info.iNum_Screen = 2;
				SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, ATTR_VISIBLE, TRUE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, ATTR_HEIGHT, 199);
			}
			else 
			{
				gDSO_Info.iNum_Screen = 1;
				SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, ATTR_VISIBLE, FALSE);
				SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, ATTR_HEIGHT, 398);
			}
			break;
	}
	return 0;
}



int CVICALLBACK ScopeDisplay (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &gDSO_Info.bScope_Display);
			if (gDSO_Info.bScope_Display) 
			{
				IM_WriteDevice("DISP ON");	

			}
			else 
			{
				IM_WriteDevice("DISP OFF");	
			}

			break;
		}
	return 0;
}



int CVICALLBACK SetTraceCallback (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	int val, error;
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			
			switch (control)
			{
				case CHANNEL_TRACE_C1:
					if (val == 1)
						IM_WriteDevice("C1:TRA ON");	
					else
						IM_WriteDevice("C1:TRA OFF");
					break;

				case CHANNEL_TRACE_C2:
					if (val == 1)
						IM_WriteDevice("C2:TRA ON");	
					else
						IM_WriteDevice("C2:TRA OFF");
					break;
						
				case CHANNEL_TRACE_C3:
					if (val == 1)
						IM_WriteDevice("C3:TRA ON");	
					else
						IM_WriteDevice("C3:TRA OFF");
					break;
			
				case CHANNEL_TRACE_C4:
					if (val == 1)
						IM_WriteDevice("C4:TRA ON");	
					else
						IM_WriteDevice("C4:TRA OFF");
					break;
			}
			error = SetTraceVisibility(control, val);
			if (error)
				SetCtrlVal(panel, control, FALSE);
		break;
	}
	return 0;					   
}




int CVICALLBACK CommandCB (int panel, int control, int event, void *callbackData, 
							int eventData1, int eventData2)
{
	int offset, line;
	char buffer[8192];
#define RD_BUFFER_SIZE		200000
	
	switch (event) 
	{
		case EVENT_KEYPRESS:
			if (gDSO_Info.ptrReadBuffer==NULL)
				gDSO_Info.ptrReadBuffer = (char*) malloc(RD_BUFFER_SIZE);
				
			if (eventData1 != VAL_ENTER_VKEY)
				return 0;
			GetCtrlAttribute (panel, control, ATTR_TEXT_SELECTION_START, &offset);
			GetTextBoxLineIndexFromOffset (panel, control, offset, &line);
			GetTextBoxLine (panel, control, line, buffer);
			if (strlen(buffer) < 2)
				return 0;
			if (strchr(buffer, '?'))
			{
				mSetRunMessage(TRUE);
				IM_QueryDevice(buffer, gDSO_Info.ptrReadBuffer, RD_BUFFER_SIZE);
				mSetRunMessage(FALSE);
				InsertTextBoxLine (panel, COMMAND_REPLY, -1, gDSO_Info.ptrReadBuffer);
				GetNumTextBoxLines (panel, COMMAND_REPLY, &line);
				SetCtrlAttribute (panel, COMMAND_REPLY, ATTR_FIRST_VISIBLE_LINE, ((line-1) < 0)? 0:line);
			}
			else
			{
				IM_WriteDevice(buffer);
			}
			break;
		case EVENT_PANEL_SIZE:
			break;
	}
	return 0;
}




int CVICALLBACK RunAllCommands_CB (int panel, int control, int event, void *callbackData, int eventData1, 
									int eventData2)
{
	int count;
	int line, ival;
	char buffer[8192];
	
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetNumTextBoxLines (panel, COMMAND_COMMAND, &count);
			for (line=0; line<count; line++)
			{
				GetTextBoxLine (panel, COMMAND_COMMAND, line, buffer);
				if (strlen(buffer) < 2)
					continue;
				if (strchr(buffer, '?'))
				{
					mSetRunMessage(TRUE);
					IM_QueryDevice(buffer, gDSO_Info.ptrReadBuffer, RD_BUFFER_SIZE);
					mSetRunMessage(FALSE);
					InsertTextBoxLine (panel, COMMAND_REPLY, -1, gDSO_Info.ptrReadBuffer);
					GetNumTextBoxLines (panel, COMMAND_REPLY, &ival);
					SetCtrlAttribute (panel, COMMAND_REPLY, ATTR_FIRST_VISIBLE_LINE, ((ival-1) < 0)? 0:ival);
				}
				else
				{
					IM_WriteDevice(buffer);
				}
			}
			break;
	}
	return 0;
}




int CVICALLBACK ClearResponseBox_CB (int panel, int control, int event, void *callbackData, int eventData1, 
									int eventData2)
{
	switch (event) 
	{
		case EVENT_COMMIT:
			ResetTextBox (panel, COMMAND_REPLY, "");
			break;
	}
	return 0;
}





int CVICALLBACK SetTimePerDiv (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double val, temp_value;
	char tmpStr[512], *strPtr;
	int i, sample_size;
	static int old_index = 20;
	double msiz;
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			// set the tdiv
			sprintf(tmpStr, "TDIV %lg", val);
			IM_WriteDevice(tmpStr);
			// update dso info
			Update_TDIV();
			// update the info box
			for (i=TRACE_1; i<MAX_TRACE_COUNT; i++) 
			{
				UpdateInfoBox(&gDSO_Info, i);
			}
			// update timebase panel
			UpdatePanel_Timebase(&gDSO_Info);
			
			GetCtrlIndex(panel, control, &old_index);
			
			UpdateCursorMeasurements(gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1);
			
			break;
	}
	return 0;
}





int CVICALLBACK SetVoltsPerDiv (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double vdiv;
	char tmpStr[512];
	int chan;
	
	
	//unsupported function in LSA1000
    //return 0;										Supported function in LTxxx and WPxxx - 12/18/2000 PW
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &vdiv);
			chan = gDSO_Info.iSelected_Channel;
			// change the vdiv
			sprintf(tmpStr, "C%d:VDIV %g", chan, vdiv);
			IM_WriteDevice(tmpStr);
			Update_DSO_Info();
			UpdateInfoBox(&gDSO_Info, chan);
			UpdatePanel_Channel(&gDSO_Info);
			break;
	}
	return 0;
}




int CVICALLBACK SetChanCoupling (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	char val1[256], tmpStr[512], rspStr[1024];
	int chan, index;
	
	
	//unsupported function in LSA1000
    //return 0;										Supported function in LTxxx and WPxxx - 12/18/2000 PW
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, val1);
			chan = gDSO_Info.iSelected_Channel;
			sprintf(tmpStr, "C%d:CPL %s", chan, val1);
			IM_WriteDevice(tmpStr);
			
			Update_Chan_Coupling();
			
			break;
	}
	return 0;
}




int CVICALLBACK SelectChannel (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	int i;
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			switch (control) 
			{
				case CHANNEL_CHN_SEL_C1:
					gDSO_Info.iSelected_Channel = TRACE_ID_C1;
					break;
				case CHANNEL_CHN_SEL_C2:
					gDSO_Info.iSelected_Channel = TRACE_ID_C2;
					break;
				case CHANNEL_CHN_SEL_C3:
					gDSO_Info.iSelected_Channel = TRACE_ID_C3;
					break;
				case CHANNEL_CHN_SEL_C4:
					gDSO_Info.iSelected_Channel = TRACE_ID_C4;
					break;
			}
			UpdatePanel_Channel(&gDSO_Info);
			for (i=TRACE_1; i<=TRACE_8; i++)
				UpdateInfoBox(&gDSO_Info, i);
			break;
	}
	return 0;
}



int CVICALLBACK SelectMathTrace (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	int i;
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			switch (control) 
			{
				case MATH_SELECT_TA:
					gDSO_Info.iSelected_Math_Trace = TRACE_ID_TA;
					break;
				case MATH_SELECT_TB:
					gDSO_Info.iSelected_Math_Trace = TRACE_ID_TB;
					break;
				case MATH_SELECT_TC:
					gDSO_Info.iSelected_Math_Trace = TRACE_ID_TC;
					break;
				case MATH_SELECT_TD:
					gDSO_Info.iSelected_Math_Trace = TRACE_ID_TD;
					break;
			}
			UpdatePanel_ZoomMath(&gDSO_Info);
			for (i=TRACE_1; i<=TRACE_8; i++)
				UpdateInfoBox(&gDSO_Info, i);
			break;
	}
	return 0;
}




int CVICALLBACK SetTriggerMode (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	

	switch (event) 
	{
		case EVENT_COMMIT:
			switch (control) 
			{
				case TIMEBASE_TRMD_STOP:
					IM_WriteDevice("TRMD STOP");
					strcpy(gDSO_Info.szTrig_Mode, "STOP");
					break;
				case TIMEBASE_TRMD_AUTO:
					IM_WriteDevice("TRMD AUTO");
					strcpy(gDSO_Info.szTrig_Mode, "AUTO");
					DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
					DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
					break;
				case TIMEBASE_TRMD_NORM:
					IM_WriteDevice("TRMD NORM");
					strcpy(gDSO_Info.szTrig_Mode, "NORM");
					DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
					DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
					break;
				case TIMEBASE_TRMD_SNGL:
					IM_WriteDevice("TRMD SINGLE");
					strcpy(gDSO_Info.szTrig_Mode, "SINGLE");
					DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
					DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
					break;
			}
			UpdatePanel_Timebase(&gDSO_Info);
			break;
	}

	return 0;
}



int CVICALLBACK SetTriggerType (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{

	char tmpStr[512];
	int val;
	int smallerswitch, largerswitch;
	double smallervalue, largervalue;
	
	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);

			if (val == TRIG_TYPE_EDGE)
			{
				SetCtrlAttribute (panel, TRIGGER_GLITCH_SET_S, ATTR_VISIBLE, 0);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_GET_S, ATTR_VISIBLE, 0);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_SET_V, ATTR_VISIBLE, 0);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_GET_V, ATTR_VISIBLE, 0);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_AT_END_OF, ATTR_VISIBLE, 0);
				
				SetCtrlAttribute (panel, TRIGGER_SLOPE, ATTR_VISIBLE, 1);
				
				sprintf(tmpStr, "TRSE %s,SR,%s", gDSO_Info.Trig[TRIG_1].szTrig_Type, gDSO_Info.szTrig_Source);

				IM_WriteDevice(tmpStr);
				
				Update_Trig_Type();
				Update_Trig_Source();
				Update_Trig_Coupling();
				Update_Trig_Level();
				Update_Trig_Slope();
				UpdatePanel_Trigger(&gDSO_Info);

			}
			else if (val == TRIG_TYPE_GLITCH)
			{
				SetCtrlAttribute (panel, TRIGGER_SLOPE, ATTR_VISIBLE, 0);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_SET_S, ATTR_VISIBLE, 1);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_GET_S, ATTR_VISIBLE, 1);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_SET_V, ATTR_VISIBLE, 1);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_GET_V, ATTR_VISIBLE, 1);
				SetCtrlAttribute (panel, TRIGGER_GLITCH_AT_END_OF, ATTR_VISIBLE, 1);

				
				GetCtrlVal(panel, TRIGGER_GLITCH_SET_S, &smallerswitch);
				GetCtrlVal(panel, TRIGGER_GLITCH_GET_S, &largerswitch);
				GetCtrlVal(panel, TRIGGER_GLITCH_SET_V, &smallervalue);
				GetCtrlVal(panel, TRIGGER_GLITCH_GET_V, &largervalue);
				
				if (smallerswitch == FALSE && largerswitch == FALSE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s", 	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
															gDSO_Info.szTrig_Source,
															gDSO_Info.Trig[TRIG_1].szTrig_Glitch_Pulse_Type);
				}
				else if (smallerswitch == TRUE && largerswitch == FALSE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s,HV,%g",	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
																	gDSO_Info.szTrig_Source,
																	gDSO_Info.Trig[TRIG_2].szTrig_Glitch_Pulse_Type,		// PS
																	gDSO_Info.Trig[TRIG_2].dTrig_Glitch_Pulse_Smaller);

				}
				else if (smallerswitch == FALSE && largerswitch == TRUE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s,HV,%g",	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
																	gDSO_Info.szTrig_Source,
																	gDSO_Info.Trig[TRIG_3].szTrig_Glitch_Pulse_Type,		// PL
																	gDSO_Info.Trig[TRIG_2].dTrig_Glitch_Pulse_Larger);
				}
				else if (smallerswitch == TRUE && largerswitch == TRUE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s,HV,%g,HV2,%g",	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
																		gDSO_Info.szTrig_Source,
																		gDSO_Info.Trig[TRIG_4].szTrig_Glitch_Pulse_Type,		// P2
																		gDSO_Info.Trig[TRIG_2].dTrig_Glitch_Pulse_Larger,
																		gDSO_Info.Trig[TRIG_2].dTrig_Glitch_Pulse_Smaller);	
				}
				
				
				IM_WriteDevice(tmpStr);

				Update_Trig_Type();
				Update_Trig_Source();
				Update_Trig_Coupling();
				Update_Trig_Level();
				Update_Trig_Slope();
				UpdatePanel_Trigger(&gDSO_Info);
			}
			
			break;
		}
	return 0;
}



int CVICALLBACK SetTriggerSlope (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	char tmpStr[512];
	int val;
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			sprintf(tmpStr, "%s:TRSL %s", gDSO_Info.szTrig_Source, (val)? "POS":"NEG");
			IM_WriteDevice(tmpStr);
			break;
	}
	return 0;
}




int CVICALLBACK SetTriggerSource (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	char val[256], tmpStr[512];
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, val);
			if (strstr(val, "LINE"))
				SetCtrlAttribute (panel, TRIGGER_COUPLING, ATTR_DIMMED, 1);
			else
				SetCtrlAttribute (panel, TRIGGER_COUPLING, ATTR_DIMMED, 0);
			sprintf(tmpStr, "TRSE EDGE,SR,%s", val);
			IM_WriteDevice(tmpStr);
			// update the DSO data structure
			Update_Trig_Source();
			// update the dso info
			Update_Trig_Coupling();
			// update the dso info
			Update_Trig_Level();
			// update the dso info
			Update_Trig_Slope();
			// update the control panel
			UpdatePanel_Timebase(&gDSO_Info);
			break;
	}
	return 0;
}



int CVICALLBACK SetTrigCoupling (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	char val[256], tmpStr[512], rspStr[1024], trg_src[128];
	
	
	// return 0; removed 05.02.2001 PW
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, val);
			IM_QueryDevice("TRSE?", rspStr, sizeof(rspStr));
			Scan(rspStr, "%s>%s[dxt44]%s[dxt44]%s[xt44]", trg_src);
			sprintf(tmpStr, "%s:TRCP %s", trg_src, val);
			IM_WriteDevice(tmpStr);
			// update the dso info
			Update_Trig_Coupling();
			// update the control panel
			UpdatePanel_Timebase(&gDSO_Info);
			break;
	}
	return 0;
}





int CVICALLBACK DefaultCallback (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	switch (event) {
		case EVENT_COMMIT:

			break;
	}
	return 0;
}




int CVICALLBACK SetTrigLevel(int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	static double x, y, vdiv, atten, offset, calc_lvl;
	char tmpStr[512], *strPtr;
	int trg_src;
	
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			// get the position of the cursor
			GetGraphCursor (gPanel_Info.hMainPanel, control, 1, &x, &y);
			// convert screen to voltage
			calc_lvl = (y/32 * vdiv * atten) + (-(offset*atten));
			// send it to the DSO
			sprintf(tmpStr, "%s:TRLV %g", gDSO_Info.szTrig_Source, calc_lvl);
			IM_WriteDevice(tmpStr);
			Update_Trig_Level();
			break;
		case EVENT_VAL_CHANGED:
			// get the position of the cursor
			GetGraphCursor (gPanel_Info.hMainPanel, control, 1, &x, &y);
			// convert screen to voltage
			calc_lvl = (y/32 * vdiv * atten) + (-(offset*atten));
			// send the value to dso
			sprintf(tmpStr, "%s:TRLV %g", gDSO_Info.szTrig_Source, calc_lvl);
			IM_WriteDevice(tmpStr);
			Update_Trig_Level();
			// update the text display
			strcpy(tmpStr, "Trigger level: ");
			strPtr = STR_MetricToString(calc_lvl, 1, "V");
			strcat(tmpStr, strPtr);
			SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxTrg_Level_Text, tmpStr);
			break;
		case EVENT_LEFT_CLICK:
			Update_Trig_Level();
			// vdiv should be the same for all channels
			trg_src = gDSO_Info.iTrig_Source;
			// other than C1 to Cn
			if (strstr(gDSO_Info.szTrig_Source, "LINE")) 
			{
				vdiv = 125.0e-3;
				atten = 1.0;
				offset = 0;
			}
			else if (strstr(gDSO_Info.szTrig_Source, "EX10")) 
			{
				vdiv = 125.0e-3;
				atten = 10.0;
				offset = 0;
			}
			else if (strstr(gDSO_Info.szTrig_Source, "EX")) 
			{
				vdiv = 125.0e-3;
				atten = 1.0;
				offset = 0;
			}
			else 
			{
				vdiv = gDSO_Info.Trace[trg_src].dVDIV;
				atten = gDSO_Info.Trace[trg_src].dAttenuation;
				offset = gDSO_Info.Trace[trg_src].dOffset;
			}
			
			break;
	}
	return 0;
}







int CVICALLBACK EnableTrigCursor (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	int val, trg_src = 0;
	double trg_level, vdiv, cursor, atten, offset, calc_lvl;
	char *strPtr, tmpStr[512];
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			Update_Trig_Level();
			// reset the cursor callback
			if (gPanel_Info.cxActive_Cursor != control) 
			{
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, ATTR_NUM_CURSORS, 0);
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, ATTR_NUM_CURSORS, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, DefaultCallback, 0);
				SetCtrlVal(gPanel_Info.cxActive_Cursor_Panel, gPanel_Info.cxActive_Cursor, FALSE);
				gPanel_Info.cxActive_Cursor = control;
				gPanel_Info.cxActive_Cursor_Panel = panel;
				SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxMeasure_Text, "");
			}
			if (val) 
			{
				if (strstr(gDSO_Info.szTrig_Source, "LINE")) 
				{
					SetCtrlVal(panel, control, FALSE);
					return 0;
				}
				// trigger source should be the same for all channels
				trg_src = gDSO_Info.iTrig_Source;
				// other than C1 to Cn
				if (strstr(gDSO_Info.szTrig_Source, "LINE")) 
				{
					vdiv = 125.0e-3;
					atten = 1.0;
					offset = 0;
				}
				else if (strstr(gDSO_Info.szTrig_Source, "EX")) 
				{
					vdiv = 125.0e-3;
					atten = 1.0;
					offset = 0;
				}
				else if (strstr(gDSO_Info.szTrig_Source, "EX10")) 
				{
					vdiv = 125.0e-3;
					atten = 10.0;
					offset = 0;
				}
				else 
				{
					vdiv = gDSO_Info.Trace[trg_src].dVDIV;
					atten = gDSO_Info.Trace[trg_src].dAttenuation;
					offset = gDSO_Info.Trace[trg_src].dOffset;
				}
				trg_level = gDSO_Info.dTrig_Level;
				
				// calculate the cursor position (32 levels per div)
				cursor = ((trg_level + (offset*atten)) / (vdiv * atten)) * 32;
				
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, ATTR_NUM_CURSORS, 1);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CURSOR_MODE, VAL_FREE_FORM);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CURSOR_COLOR, VAL_WHITE);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CROSS_HAIR_STYLE, VAL_HORIZONTAL_LINE);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CURSOR_POINT_STYLE, VAL_NO_POINT);
				SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, 0, cursor);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, SetTrigLevel, 0);
				// update the text display
				calc_lvl = atten * trg_level;
				strcpy(tmpStr, "Trigger level: ");
				strPtr = STR_MetricToString(calc_lvl, 1, "V");
				strcat(tmpStr, strPtr);
				SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxTrg_Level_Text, tmpStr);
			}
			else 
			{
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, ATTR_NUM_CURSORS, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, DefaultCallback, 0);
				SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxTrg_Level_Text, "");
			}
			
			break;
	}
	return 0;
}




int CVICALLBACK SetMathFunction (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	char fname[512], tmpStr[1024];
	int result;
	FILE *fstream;
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			result = FileSelectPopup ("", "*.mth", "*.mth;*.txt", "Load Math Function", VAL_LOAD_BUTTON, 0, 0, 1, 1, fname);
			if (result != VAL_EXISTING_FILE_SELECTED)
				return 0;
				
			fstream = fopen (fname, "r");
			if (!fstream)
			{
				MessagePopup("ERROR", "Unable to open file.");
				return 0;
			}
			
			while (fgets (tmpStr, sizeof(tmpStr), fstream))
			{
				if (strchr(tmpStr, '?'))
					continue;// will not send query command
				IM_WriteDevice(tmpStr);
			}
			fclose(fstream);
			break;
	}
	return 0;
}



int CVICALLBACK SetTrigDelay (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double val;
	char tmpStr[512];
	
	switch (event) {
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			sprintf(tmpStr, "TRDL %.0f", val);
			IM_WriteDevice(tmpStr);
			Update_Trig_Delay();
			UpdatePanel_Timebase(&gDSO_Info);
			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &val);
			sprintf(tmpStr, "TRDL %.0f", val);
			IM_WriteDevice(tmpStr);
			DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
			DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
			break;
	}
	return 0;
}


int CVICALLBACK SetGlitchTrigger (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	char tmpStr[512], trig_source[32],  trig_coupling[32];
	int	trig_type, trig_slope, smaller_switch, larger_switch;
	double smaller_value, larger_value;
	
	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal(panel, TRIGGER_TYPE, &trig_type);
			

			if (trig_type == TRIG_TYPE_EDGE)
			{
				sprintf(tmpStr, "TRSE %s,SR,%s", gDSO_Info.Trig[TRIG_1].szTrig_Type, gDSO_Info.szTrig_Source);
				IM_WriteDevice(tmpStr);
				
				Update_Trig_Source();
				Update_Trig_Coupling();
				Update_Trig_Level();
				Update_Trig_Slope();
				UpdatePanel_Trigger(&gDSO_Info);
			}
			
			else if (trig_type == TRIG_TYPE_GLITCH)
			{
				GetCtrlVal(panel, TRIGGER_SOURCE, trig_source);
				GetCtrlVal(panel, TRIGGER_SLOPE, &trig_slope);
				GetCtrlVal(panel, TRIGGER_COUPLING, trig_coupling);
				GetCtrlVal(panel, TRIGGER_GLITCH_SET_V, &smaller_value);
				GetCtrlVal(panel, TRIGGER_GLITCH_GET_V, &larger_value);
				GetCtrlVal(panel, TRIGGER_GLITCH_SET_S, &smaller_switch);
				GetCtrlVal(panel, TRIGGER_GLITCH_GET_S, &larger_switch);
				
				if (smaller_switch == FALSE && larger_switch == FALSE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s", 	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
															gDSO_Info.szTrig_Source,
															gDSO_Info.Trig[TRIG_1].szTrig_Glitch_Pulse_Type);
				}
				else if (smaller_switch == TRUE && larger_switch == FALSE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s,HV,%g",	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
																	gDSO_Info.szTrig_Source,
																	gDSO_Info.Trig[TRIG_2].szTrig_Glitch_Pulse_Type,		// PS
																	smaller_value);

				}
				else if (smaller_switch == FALSE && larger_switch == TRUE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s,HV,%g",	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
																	gDSO_Info.szTrig_Source,
																	gDSO_Info.Trig[TRIG_3].szTrig_Glitch_Pulse_Type,		// PL
																	larger_value);
				}
				else if (smaller_switch == TRUE && larger_switch == TRUE)
				{
					sprintf(tmpStr, "TRSE %s,SR,%s,HT,%s,HV,%g,HV2,%g",	gDSO_Info.Trig[TRIG_2].szTrig_Type, 
																		gDSO_Info.szTrig_Source,
																		gDSO_Info.Trig[TRIG_4].szTrig_Glitch_Pulse_Type,		// P2
																		larger_value,
																		smaller_value);	
				}
				IM_WriteDevice(tmpStr);
			}
			break;
		}
	return 0;
}



int CVICALLBACK FindGainOffset (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	char tmpStr[512];
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			sprintf(tmpStr, "C%d:ASET FIND", gDSO_Info.iSelected_Channel);
			IM_WriteDevice(tmpStr);
			Update_DSO_Info();
			UpdatePanel_Channel(&gDSO_Info);
			UpdateInfoBox(&gDSO_Info, gDSO_Info.iSelected_Channel);
			break;
	}																   
	return 0;
}


int CVICALLBACK SetChanOffset (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double val, atten;
	char tmpStr[512];
	
	switch (event) 
	{
		case EVENT_COMMIT:
				GetCtrlVal(panel, control, &val);
				// get attenuation factor
				atten = gDSO_Info.Trace[gDSO_Info.iSelected_Channel].dAttenuation;
				sprintf(tmpStr, "C%d:OFST %f", gDSO_Info.iSelected_Channel, val/atten);
				IM_WriteDevice(tmpStr);
				Update_Chan_Offset();
				DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
				DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
			break;
		case EVENT_VAL_CHANGED:
				GetCtrlVal(panel, control, &val);
				// get attenuation factor
				atten = gDSO_Info.Trace[gDSO_Info.iSelected_Channel].dAttenuation;
				sprintf(tmpStr, "C%d:OFST %f", gDSO_Info.iSelected_Channel, val/atten);
				IM_WriteDevice(tmpStr);
				Update_Chan_Offset();
				DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
				DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
			break;
	}
	return 0;
}



int CVICALLBACK SetSampleSize (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	char tmpStr[512], val[50], *strPtr, *strPtr2;
	int index;

	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, val);
			sprintf(tmpStr, "MSIZ %s", val);
			IM_WriteDevice(tmpStr);
			// Update dso info
			Update_Memory_Size();
			// update the control panel
			UpdatePanel_Timebase(&gDSO_Info);
			break;
	}
	return 0;
}





int CVICALLBACK SetMeasureCursor(int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{


	switch (event) {
		case EVENT_COMMIT:
			if (gDSO_Info.iSelected_Channel == NO_VALUE)
				break;
			UpdateCursorMeasurements(panel, control);
			break;
		case EVENT_VAL_CHANGED:
			if (gDSO_Info.iSelected_Channel == NO_VALUE)
				break;
			UpdateCursorMeasurements(panel, control);
			break;
		case EVENT_LEFT_CLICK:
			if (gDSO_Info.iSelected_Channel == NO_VALUE)
				break;
			break;
	}
	
	return 0;

}



int CVICALLBACK EnableMeasureCursor (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	int val;
	double x1, x2, y1, y2;
	char tmpStr[512], *strPtr;
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &val);
			// reset the curosr callback
			if (gPanel_Info.cxActive_Cursor != control) 
			{
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, ATTR_NUM_CURSORS, 0);
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, ATTR_NUM_CURSORS, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, DefaultCallback, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, DefaultCallback, 0);
				SetCtrlVal(gPanel_Info.cxActive_Cursor_Panel, gPanel_Info.cxActive_Cursor, FALSE);
				gPanel_Info.cxActive_Cursor = control;
				gPanel_Info.cxActive_Cursor_Panel = panel;
				SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxTrg_Level_Text, "");
			}
			if (val) 
			{
				Update_DSO_Info();
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, ATTR_NUM_CURSORS, 2);
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, ATTR_NUM_CURSORS, 2);
				// voltage  and time cursors for screen 1
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CURSOR_MODE, VAL_FREE_FORM);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CURSOR_COLOR, VAL_WHITE);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CROSS_HAIR_STYLE, VAL_SHORT_CROSS);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, ATTR_CURSOR_POINT_STYLE, VAL_NO_POINT);
				
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 2, ATTR_CURSOR_MODE, VAL_FREE_FORM);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 2, ATTR_CURSOR_COLOR, VAL_WHITE);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 2, ATTR_CROSS_HAIR_STYLE, VAL_SHORT_CROSS);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 2, ATTR_CURSOR_POINT_STYLE, VAL_NO_POINT);
				// voltage  and time cursors for screen 2
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 1, ATTR_CURSOR_MODE, VAL_FREE_FORM);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 1, ATTR_CURSOR_COLOR, VAL_WHITE);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 1, ATTR_CROSS_HAIR_STYLE, VAL_SHORT_CROSS);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 1, ATTR_CURSOR_POINT_STYLE, VAL_NO_POINT);
				
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 2, ATTR_CURSOR_MODE, VAL_FREE_FORM);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 2, ATTR_CURSOR_COLOR, VAL_WHITE);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 2, ATTR_CROSS_HAIR_STYLE, VAL_SHORT_CROSS);
				SetCursorAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 2, ATTR_CURSOR_POINT_STYLE, VAL_NO_POINT);
				
				x1 = 0;
				x2 = 0;
				y1 = 16;
				y2 = -16;
				
				SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, x1, y1);
				SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 2, x2, y2);
				
				SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 1, x1, y1);
				SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 2, x2, y2);
				
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, SetMeasureCursor, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, SetMeasureCursor, 0);
			
				
				gDSO_Info.bMeasureCursorOn = TRUE;
				
				UpdateCursorMeasurements(gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1);
				
			}
			else 
			{
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, ATTR_NUM_CURSORS, 0);
				SetCtrlAttribute (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, ATTR_NUM_CURSORS, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, DefaultCallback, 0);
				InstallCtrlCallback (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, DefaultCallback, 0);
				SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxMeasure_Text, "");
				
				gDSO_Info.bMeasureCursorOn = FALSE;
			}
			break;
	}
	return 0;
}





int CVICALLBACK SetVPOS (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{

	switch (event) 
	{
		case EVENT_COMMIT:
			break;
		case EVENT_VAL_CHANGED:
			break;
	}
	
	
	return 0;

}



int CVICALLBACK SetHPOS (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{

	double d_val;
	char tmpStr[512];
	
	switch (event) 
	{
		case EVENT_COMMIT:
			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "");
			break;
	}
	
	
	return 0;

}

int CVICALLBACK SetTriggerDelay (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double d_val, inc_val;
	char tmpStr[512];
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &d_val);
			// if the value is less than 1 then convert to delay in seconds
			if (d_val < 1.0)
				d_val *= -1.0;
			sprintf(tmpStr, "TRDL %g", d_val);
			IM_WriteDevice(tmpStr);
			Update_Trig_Delay();
			UpdatePanel_Timebase(&gDSO_Info);
			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &d_val);
			// if the value is less than 1 then convert to delay in seconds
			if (d_val < 1.0)
				d_val *= -1.0;
			sprintf(tmpStr, "TRDL %g", d_val);
			IM_WriteDevice(tmpStr);
			Update_Trig_Delay();
			UpdatePanel_Timebase(&gDSO_Info);
			break;
	}
	return 0;
}


int CVICALLBACK SetHMAG (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double d_val;
	char tmpStr[512];
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:HMAG %g", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			Update_HMAG();
//			UpdatePanel_HMAG(&gDSO_Info);

			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:HMAG %g", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			Update_HMAG();
			break;
	}
	return 0;
}


int CVICALLBACK GetHMAG (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	//double d_val;
	int i_val;
	char tmpStr[512];
	
//	switch (event) 
//	{
//		case EVENT_COMMIT:
//			GetCtrlVal(panel, control, &i_val);
			sprintf(tmpStr, "%s:HMAG?", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name);
			IM_WriteDevice(tmpStr);
			IM_QueryDevice(tmpStr, gDSO_Info.ptrReadBuffer, RD_BUFFER_SIZE);

//			break;
//		case EVENT_VAL_CHANGED:
//			GetCtrlVal(panel, control, &i_val);
//			sprintf(tmpStr, "%s:HMAG %d", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, i_val);
//			IM_WriteDevice(tmpStr);
//			break;
//	}

	
	
	return 0;
}



int CVICALLBACK SetVMAG (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	double d_val;
	char tmpStr[512];
	
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:VMAG %f", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			Update_VMAG();
			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:VMAG %f", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			Update_VMAG();
			break;
	}
	return 0;
}

int CVICALLBACK SetZoomOffset (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	
	double d_val;
	char tmpStr[512];

	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:VPOS %f", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].dZoom_Offset = d_val;  // dval * 32
			Update_VPOS();
			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:VPOS %f", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].dZoom_Offset = d_val;
			Update_VPOS();
			break;
	}
	return 0;
}

int CVICALLBACK SetZoomPosition (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	
	double d_val;
	char tmpStr[512];
	
	switch (event) 
	{
		case EVENT_COMMIT:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:HPOS %f", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			Update_HPOS();
			break;
		case EVENT_VAL_CHANGED:
			GetCtrlVal(panel, control, &d_val);
			sprintf(tmpStr, "%s:HPOS %f", gDSO_Info.Trace[gDSO_Info.iSelected_Math_Trace].szTrace_Name, d_val);
			IM_WriteDevice(tmpStr);
			Update_HPOS();
			break;
	}
	return 0;
}



int CVICALLBACK CB_Timer (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	int led;
	
	switch (event) 
	{
		case EVENT_TIMER_TICK:
			SuspendTimerCallbacks ();
			UpdateTrace();
			ProcessSystemEvents();
			ResetTimer (panel, control);
			ResumeTimerCallbacks ();
			break;
	}
	return 0;
}



#if defined ENABLE_TEST_TOOLS

int CVICALLBACK CB_TestTools (int panel, int control, int event, void *callbackData, 
								int eventData1, int eventData2)
{
	static int loaded_flag = FALSE;
	
	
	if (loaded_flag)
		return 0;
		
	switch (event) 
	{
		case EVENT_COMMIT:
			if (gDSO_Info.bToolsEnabled != TRUE)
			{
				Beep();
				MessagePopup("Message", "Function not enabled");
				return 0;
			}
			loaded_flag = TRUE;
			FE_Utils(NULL);
			loaded_flag = FALSE;
			break;
	}
	return 0;
}

#endif



int CVICALLBACK ResetMath_CB (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{

	int i;
	
	switch (event) 
	{
		case EVENT_COMMIT:
			IM_WriteDevice("TA:VMAG 1.0;TA:VPOS 0.0;TA:HMAG 1.0;TA:HPOS 5.0");
			IM_WriteDevice("TB:VMAG 1.0;TB:VPOS 0.0;TB:HMAG 1.0;TB:HPOS 5.0");
			IM_WriteDevice("TC:VMAG 1.0;TC:VPOS 0.0;TC:HMAG 1.0;TC:HPOS 5.0");
			IM_WriteDevice("TD:VMAG 1.0;TD:VPOS 0.0;TD:HMAG 1.0;TD:HPOS 5.0");
			Update_HMAG();
			Update_HPOS();
			Update_VMAG();
			Update_VPOS();
			UpdatePanel_ZoomMath(&gDSO_Info);
			for (i=TRACE_1; i<=TRACE_8; i++)
				UpdateInfoBox(&gDSO_Info, i);
			break;
	}
	return 0;
}


int CVICALLBACK Path (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	char path[512];
	int error;

	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal(panel, DATALOGGER_PATH, path);
			error = DirSelectPopup (path, "Select Directory", 1, 1, path);
			SetCtrlVal(panel, DATALOGGER_PATH, path);
			break;
		}
	return 0;
}


int CVICALLBACK BrowseDir (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	
	char path[512];
	int error;
	
	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal(panel, DATALOGGER_PATH, path);
			error = DirSelectPopup (path, "Select Directory", 1, 1, path);
			SetCtrlVal(panel, DATALOGGER_PATH, path);
			break;
		}
	return 0;
}



int CVICALLBACK NoOfAcquisitions (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	switch (event)
		{
		case EVENT_COMMIT:

			break;
		}
	return 0;
}


int CVICALLBACK StopDatalogger (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	switch (event)
		{
		case EVENT_COMMIT:
			no_of_acquisitions = 1;
			IM_WriteDevice("TRMD STOP");
			strcpy(gDSO_Info.szTrig_Mode, "STOP");
			UpdatePanel_Timebase(&gDSO_Info);
			break;
		}
	return 0;
}


int CVICALLBACK StartAcquisition (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	
	int  index, stop_datalogger, ii, jj, traceHandle;
	char tmpStr[512], path[512], filename[512];
	
	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal (gPanel_Info.hDataloggerPanel, DATALOGGER_NO_OF_ACQUISITIONS, &no_of_acquisitions);
			IM_WriteDevice("TRMD SINGLE");
			strcpy(gDSO_Info.szTrig_Mode, "SINGLE");
			for (ii=0; ii<no_of_acquisitions; ii++)
			{
				GetCtrlVal (gPanel_Info.hDataloggerPanel, DATALOGGER_STOP_DATALOGGER, &stop_datalogger);
				// continue if Stop was not pressed on the Datalogger tab
				IM_WriteDevice("arm;wait 5.0");
				UpdateTrace ();
			}
			
			break;
		}
	return 0;
}


int CVICALLBACK Datalogger (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	BOOL b_val;
	
	switch (event)
		{
		case EVENT_COMMIT:
			GetCtrlVal(panel, gPanel_Info.Datalogger_Controls.cxDatalogger, &b_val);
			

			break;
		}
	return 0;
}
