/*
 *			Remote LSA
 *
 *			Copyright (c) 1998 LeCroy Corporation
 *			
 *			Written By: Ricardo Palacio
 *
 *			April, 1998
 *
 *
 */


/* 
 * $Header: /Test Framework 3/900040 Software Apps/LSA1000 GS/Net LSA/update_panel.c 2     6/22/98 1:26p Ricardop $
 * $Log: /Test Framework 3/900040 Software Apps/LSA1000 GS/Net LSA/update_panel.c $
 * 
 * 2     6/22/98 1:26p Ricardop
 * added gpib driver
 * 
 * 1     4/27/98 4:53p Ricardop
 * Initial check-in
 * 
 */

#include <ansi_c.h>
#include <utility.h>
#include <userint.h>
#include <toolbox.h>
#include <analysis.h>
#include <formatio.h>
#include <toolbox.h>


// LeCroy Libs.
#include <interface.h>
#include <dsopanel.h>
#include <global_info.h>
#include <str_utils.h>
#include <update_panel.h>








static ULONG tmp_Get_Trace_Size(void)
{

	int i;
	char rspStr[1024], tmpStr[512];
	double d_val, d_val1, d_val2;

	//Update the trace size;
	IM_QueryDevice("C1:CRST? PREF, PDIF", rspStr, sizeof(rspStr));
	Scan(rspStr, "%s>%s[dt#]%f%s[dt#]%f", &d_val1, &d_val2);
	IM_WriteDevice("C1:CRST PREF, 0");
	IM_WriteDevice("C1:CRST PDIF, 10");
	IM_QueryDevice("PAVA? PNTS", rspStr, sizeof(rspStr));
	Scan(rspStr, "%s>%s[dt#]%f", &d_val);
	sprintf(tmpStr, "C1:CRST PREF, %lf, PDIF, %lf", d_val1, d_val2);
	IM_WriteDevice(tmpStr);
	
	return d_val;
	
}





int UpdatePanel_Channel(DSO_INFO *dso_info) 
{

	int chan, index;
	double vdiv, offset_limit, offset, atten, calc_vdiv;
	char *strPtr, *strPtr2, tmpStr[512];
	
	
	chan = dso_info->iSelected_Channel;
	if (chan == NO_VALUE)
		return -1;
	
	// update the buttons
	SetCtrlVal(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxChan_Select[CHANNEL_1], FALSE);
	SetCtrlVal(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxChan_Select[CHANNEL_2], FALSE);
	SetCtrlVal(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxChan_Select[CHANNEL_3], FALSE);
	SetCtrlVal(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxChan_Select[CHANNEL_4], FALSE);
	SetCtrlVal(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxChan_Select[chan], TRUE);
	
	// get the attenuation
	atten = dso_info->Trace[chan].dAttenuation;
	// get the vdiv
	vdiv = dso_info->Trace[chan].dVDIV;
	// get the offset
	offset = dso_info->Trace[chan].dOffset;
	
	// update vdiv control
	GetIndexFromValue (gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxVDIV, &index, vdiv);
	SetCtrlIndex(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxVDIV, (index<0)?0:index);
	// find the offset setting
	// 10, 5, 2, 1 V/div.
	calc_vdiv = vdiv * atten;
	if (calc_vdiv > 0.5) 
		offset_limit = 100.0;
	// 0.5, 0.2, 0.1 V/div
	else if ((calc_vdiv < 1.0)&&(calc_vdiv > 0.05))
		offset_limit = 10.0;
	// 50mV, 20mV, 10mV, 5mV /div
	else if ((calc_vdiv < 0.1)&&(calc_vdiv > 0.002))
		offset_limit = 1.0;
	// 2mV/div
	else 
		offset_limit = 0.4;
	
	// update the coupling
	strcpy(tmpStr, dso_info->Trace[chan].szChan_Coupling);
	GetIndexFromValue (gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxCoupling, &index, tmpStr);
	SetCtrlIndex(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxCoupling, (index<0)?0:index);
	
	// update offset range
	SetCtrlAttribute(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxOffset, ATTR_MIN_VALUE, (-offset_limit));
	SetCtrlAttribute(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxOffset, ATTR_MAX_VALUE, offset_limit);
	SetCtrlAttribute(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxOffset, ATTR_INCR_VALUE, calc_vdiv/32.0);
	SetCtrlVal(gPanel_Info.hChannelPanel, gPanel_Info.Channel_Controls.cxOffset, offset*atten);
	
	// clear the plot
	DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
	DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
	

	return 0;
}







int UpdateSampleRateInfo(void)
{

	int sample_size;
	double tdiv, temp_value;
	char *strPtr;
	char tmpStr[1024];
	
	
	
	sample_size = gDSO_Info.Trace[TRACE_1].ulTrace_Size;
	tdiv = gDSO_Info.dTDIV;
	
	// update the sampling message
	strPtr = STR_MetricToString(sample_size, 0, " Samples at\n");
	strcpy(tmpStr, strPtr);
	temp_value = sample_size/(tdiv*10);
	strPtr = STR_MetricToString(temp_value, 0, "S/s\n");
	strcat(tmpStr, strPtr);
	temp_value = (tdiv*10)/sample_size;
	strPtr = STR_MetricToString(temp_value, 0, "s/pt\n");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "for ");
	temp_value = tdiv*10;
	strPtr = STR_MetricToString(temp_value, 0, "s\n");
	strcat(tmpStr, strPtr);
	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxSample_Rate_Text, tmpStr);

	return 0;
}



int UpdatePanel_Timebase(DSO_INFO *dso_info) 
{
	
	double d_val, tdiv;
	char tmpStr[512], *strPtr, *strPtr2, trg_src[50];
	int index, i_val;
	double pref, pdif, inc_val;
	ULONG color;
	
	
	
	// get tdiv
	tdiv = dso_info->dTDIV;
	// refresh the tdiv control
	GetIndexFromValue (gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxTDIV, &index, tdiv);
	SetCtrlIndex(gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxTDIV, (index<0)?0:index);
	
	// get the memory size and update the control panel
	GetIndexFromValue (gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxSample_Size, 
											&index, dso_info->szMemory_Size);
	SetCtrlIndex(gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxSample_Size, (index<0)?0:index);
	
	// get the DELAY and update the control panel
	if (dso_info->dTrig_Delay < 0) 
	{
		d_val = -(dso_info->dTrig_Delay);
		inc_val = dso_info->dTDIV / 10.0;
		SetCtrlAttribute(gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxDelay, 
																ATTR_INCR_VALUE, inc_val);
	}
	else 
	{
		d_val = dso_info->dTrig_Delay;
		SetCtrlAttribute(gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxDelay, 
																	ATTR_INCR_VALUE, 1.0);
	}
	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Timebase_Controls.cxDelay_Slide, d_val);
	SetCtrlVal(gPanel_Info.hTimebasePanel, gPanel_Info.Timebase_Controls.cxDelay, d_val);
	
	// update the trigger mode
	strcpy(tmpStr, dso_info->szTrig_Mode);
	if (strstr(tmpStr, "STOP"))
		strcpy(tmpStr, "STOPPED");
	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxTrig_Mode_Text, tmpStr);

	return 0;

}


int UpdatePanel_Trigger(DSO_INFO *dso_info) 
{
	
	double d_val, tdiv;
	char tmpStr[512], *strPtr, *strPtr2, trg_src[50];
	int index, i_val;
	double pref, pdif, inc_val;
	ULONG color;
	
	// get the trigger type and update the control panel
	
	strcpy(tmpStr, dso_info->szTrig_Type);
	if (strstr(tmpStr, "EDGE"))
	{
		SetCtrlVal(gPanel_Info.hTriggerPanel, gPanel_Info.Trigger_Controls.cxType, TRIG_TYPE_EDGE);
	
		SetCtrlAttribute (gPanel_Info.hTriggerPanel, TRIGGER_GLITCH_SET_S, ATTR_VISIBLE, 0);
		SetCtrlAttribute (gPanel_Info.hTriggerPanel, TRIGGER_GLITCH_GET_S, ATTR_VISIBLE, 0);
		SetCtrlAttribute (gPanel_Info.hTriggerPanel, TRIGGER_GLITCH_SET_V, ATTR_VISIBLE, 0);
		SetCtrlAttribute (gPanel_Info.hTriggerPanel, TRIGGER_GLITCH_GET_V, ATTR_VISIBLE, 0);
		SetCtrlAttribute (gPanel_Info.hTriggerPanel, TRIGGER_GLITCH_AT_END_OF, ATTR_VISIBLE, 0);
			
		SetCtrlAttribute (gPanel_Info.hTriggerPanel, TRIGGER_SLOPE, ATTR_VISIBLE, 1);

	}
	
	// get the trigger source and update the control panel
	GetIndexFromValue (gPanel_Info.hTriggerPanel, gPanel_Info.Trigger_Controls.cxSource, 
													&index, dso_info->szTrig_Source);
	SetCtrlIndex(gPanel_Info.hTriggerPanel, gPanel_Info.Trigger_Controls.cxSource, (index<0)?0:index);
	// get the coupling and update the control panel
	GetIndexFromValue (gPanel_Info.hTriggerPanel, gPanel_Info.Trigger_Controls.cxCoupling, 
													&index, dso_info->szTrig_Coupling);
	SetCtrlIndex(gPanel_Info.hTriggerPanel, gPanel_Info.Trigger_Controls.cxCoupling, (index<0)?0:index);
	// get the trigger slope and update the control panel
	SetCtrlIndex(gPanel_Info.hTriggerPanel, gPanel_Info.Trigger_Controls.cxSlope, 
										dso_info->bTrig_Slope);

	return 0;
}



int UpdatePanel_ZoomMath(DSO_INFO *dso_info) 
{
	int trace_idx, chan;
	double hmag, hpos, vmag, vpos;

	
	chan = dso_info->iSelected_Math_Trace;
	if (chan == NO_VALUE)
		return -1;

	
	trace_idx = dso_info->iSelected_Math_Trace - (MAX_CHANNEL_COUNT-1);
	if (trace_idx < 1) 
	{
		dso_info->iSelected_Math_Trace = TRACE_ID_TA;
		trace_idx = 1;
	}
	

	// get HMAG
	hmag = gDSO_Info.Trace[chan].dZoom_HMAG;
	
	// get HPOS
	hpos = gDSO_Info.Trace[chan].dZoom_Position;
	
	// get VMAG
	vmag = gDSO_Info.Trace[chan].dZoom_VMAG;
	
	// get VPOS
	vpos = gDSO_Info.Trace[chan].dZoom_Offset;
	
	
	
	// update the buttons
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxTrace_Select[TRACE_1], FALSE);
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxTrace_Select[TRACE_2], FALSE);
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxTrace_Select[TRACE_3], FALSE);
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxTrace_Select[TRACE_4], FALSE);
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxTrace_Select[trace_idx], TRUE);

	// update HMAG
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxHMAG, hmag);
									   
	// update HPOS
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxPosition, hpos);
									   
	// update VMAG
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxVMAG, vmag);
									   
	// update VPOS
	SetCtrlVal(gPanel_Info.hMathPanel, gPanel_Info.Zoom_Math_Controls.cxOffset, vpos);


	return 0;

}






int FindAvailableInfoBox(TRACE_INFO *trace_info)
{

	int index;
	
	
	// try to get an available trace info box
	if (trace_info->iInfoBox_Index == NO_VALUE) 
	{
		for (index=TRACE_1; index<MAX_TRACE_DISPLAYED; index++) 
		{
			if (gPanel_Info.Info_Box[index].bDisplayed != TRUE) 
			{
				trace_info->iInfoBox_Index = index;
				gPanel_Info.Info_Box[index].bDisplayed = TRUE;
				return TRUE;
			}
		}
		if (trace_info->iInfoBox_Index == NO_VALUE)
			return FALSE;//non found
	}
	
	// an info box is already assigned
	return FALSE;

}





int UpdateInfoBox(DSO_INFO *dso_info, int trace_idx)
{
	
	int index, chan;
	char *strPtr, tmpStr[512];
	double vdiv, tdiv, atten;
	
	
	
	index = dso_info->Trace[trace_idx].iInfoBox_Index;
	if (index == NO_VALUE)
		return -1;
	
	switch (dso_info->Trace[trace_idx].Trace_ID) 
	{
		case TRACE_ID_C1:
			chan = CHANNEL_1;
			break;
		case TRACE_ID_C2:
			chan = CHANNEL_2;
			break;
		case TRACE_ID_C3:
			chan = CHANNEL_3;
			break;
		case TRACE_ID_C4:
			chan = CHANNEL_4;
			break;
		default:
			chan = NO_VALUE;
			break;
	}
	if (chan != NO_VALUE) 
	{
		vdiv = dso_info->Trace[trace_idx].dVDIV * dso_info->Trace[trace_idx].dAttenuation;
		tdiv = dso_info->dTDIV;
	} 
	else 
	{
		vdiv = 0.0;
		tdiv = 0.0;
	}
	// set vdiv label
	strPtr = STR_MetricToString(vdiv, 0, "V");
	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxVDIV_Message, strPtr);
	
	// set tdiv label
	strPtr = STR_MetricToString(tdiv, 0, "s");
	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxTDIV_Message, strPtr);
	
	// set the box label
	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxBox_Label, 
				dso_info->Trace[trace_idx].szTrace_Name);
				
	// set the box label color
	SetCtrlAttribute (gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxBox_Label,
                  			ATTR_TEXT_BGCOLOR, dso_info->Trace[trace_idx].ulTrace_Color);	

	// set the box color
	if ((gDSO_Info.iSelected_Channel==dso_info->Trace[trace_idx].Trace_ID)||
		(gDSO_Info.iSelected_Math_Trace==dso_info->Trace[trace_idx].Trace_ID))
		SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxBorder, ATTR_FRAME_COLOR, 
					dso_info->Trace[trace_idx].ulTrace_Color);
	else 
		SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxBorder, ATTR_FRAME_COLOR, VAL_GRAY);
	
	// display the box
	SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxBorder, 
												ATTR_VISIBLE, dso_info->Trace[trace_idx].bTrace_ON);
	SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxVDIV_Message, 
												ATTR_VISIBLE, dso_info->Trace[trace_idx].bTrace_ON);
	SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxTDIV_Message, 
												ATTR_VISIBLE, dso_info->Trace[trace_idx].bTrace_ON);
	SetCtrlAttribute(gPanel_Info.hMainPanel, gPanel_Info.Info_Box[index].cxBox_Label, 
												ATTR_VISIBLE, dso_info->Trace[trace_idx].bTrace_ON);
	
	// remove assignment when box is hidden
	if (dso_info->Trace[trace_idx].bTrace_ON == FALSE) 
	{
		gPanel_Info.Info_Box[dso_info->Trace[trace_idx].iInfoBox_Index].bDisplayed = FALSE;
		dso_info->Trace[trace_idx].iInfoBox_Index = NO_VALUE;
	}
	
	//remove the trace from the plot when trace is disabled
	DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_DELAYED_DRAW);
	DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_DELAYED_DRAW);
	
	return 0;

}






int UpdateCursorMeasurements(int panel, int control)
{

	double x1, x2, y1, y2, t1, t2, v1, v2, freq;
	static double vdiv, tdiv, atten, half_screen, trig_offset, chan_offset;
	char tmpStr[512], *strPtr;

	
	if (gDSO_Info.bMeasureCursorOn != TRUE)
		return 0;
	
	GetGraphCursor (panel, control, 1, &x1, &y1);
	GetGraphCursor (panel, control, 2, &x2, &y2);
	
	if (control==MAINPANEL_SCREEN_2)
	{
		SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 1, x1, y1);
		SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_1, 2, x2, y2);
	}
	else
	{
		SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 1, x1, y1);
		SetGraphCursor (gPanel_Info.hMainPanel, MAINPANEL_SCREEN_2, 2, x2, y2);
	}

	
	vdiv = gDSO_Info.Trace[gDSO_Info.iSelected_Channel].dVDIV;
	tdiv = gDSO_Info.dTDIV;
	atten = gDSO_Info.Trace[gDSO_Info.iSelected_Channel].dAttenuation;
	half_screen = (double) gDSO_Info.Trace[gDSO_Info.iSelected_Channel].ulTrace_Size;
	half_screen /= 2.0;
	trig_offset = gDSO_Info.dTrig_Delay;
	trig_offset = (trig_offset/100) * (double) gDSO_Info.Trace[gDSO_Info.iSelected_Channel].ulTrace_Size;
	chan_offset = gDSO_Info.Trace[gDSO_Info.iSelected_Channel].dOffset;
	chan_offset *= atten;
	
	
	
	v1 = ((y1/32.0) * vdiv * atten) - chan_offset;
	v2 = ((y2/32.0) * vdiv * atten) - chan_offset;
	t1 = (x1+half_screen-trig_offset)/(half_screen/5.0) * tdiv;
	t2 = (x2+half_screen-trig_offset)/(half_screen/5.0) * tdiv;

	strcpy(tmpStr, "V1 ");
	strPtr = STR_MetricToString(v1, 2, "V");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "     V2 ");
	strPtr = STR_MetricToString(v2, 2, "V\n");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "T1 ");
	strPtr = STR_MetricToString(t1, 2, "s");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "     T2 ");
	strPtr = STR_MetricToString(t2, 2, "s\n\n");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "Voltage: ");
	strPtr = STR_MetricToString(v1-v2, 2, "V\n");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "Time:");
	strPtr = STR_MetricToString(t1-t2, 2, "s\n");
	strcat(tmpStr, strPtr);
	strcat(tmpStr, "Frequency: ");
	freq = 1.0/(t1-t2);
	strPtr = STR_MetricToString(freq, 2, "Hz\n");
	strcat(tmpStr, strPtr);

	SetCtrlVal(gPanel_Info.hMainPanel, gPanel_Info.Misc_Controls.cxMeasure_Text, tmpStr);

	return 0;
}




int SetTraceVisibility(int control, int state)
{
	
	int i;

	
	DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen1, -1, VAL_IMMEDIATE_DRAW);
	DeleteGraphPlot (gPanel_Info.hMainPanel, gPanel_Info.cxScreen2, -1, VAL_IMMEDIATE_DRAW);
	
	switch (control) 
	{
		case CHANNEL_TRACE_C1:
			i = TRACE_1;
			if (state)
				gDSO_Info.iSelected_Channel = TRACE_ID_C1;
			UpdatePanel_Channel(&gDSO_Info);
			break;
		case CHANNEL_TRACE_C2:
			i = TRACE_2;
			if (state)
				gDSO_Info.iSelected_Channel = TRACE_ID_C2;
			UpdatePanel_Channel(&gDSO_Info);
			break;
		case CHANNEL_TRACE_C3:
			i = TRACE_3;
			if (state)
				gDSO_Info.iSelected_Channel = TRACE_ID_C3;
			UpdatePanel_Channel(&gDSO_Info);
			break;
		case CHANNEL_TRACE_C4:
			i = TRACE_4;
			if (state)
				gDSO_Info.iSelected_Channel = TRACE_ID_C4;
			UpdatePanel_Channel(&gDSO_Info);
			break;
		case MATH_TRACE_TA:
			i = TRACE_5;
			gDSO_Info.iSelected_Math_Trace = TRACE_ID_TA;
			UpdatePanel_ZoomMath(&gDSO_Info);
			break;
		case MATH_TRACE_TB:
			i = TRACE_6;
			gDSO_Info.iSelected_Math_Trace = TRACE_ID_TB;
			UpdatePanel_ZoomMath(&gDSO_Info);
			break;
		case MATH_TRACE_TC:
			i = TRACE_7;
			gDSO_Info.iSelected_Math_Trace = TRACE_ID_TC;
			UpdatePanel_ZoomMath(&gDSO_Info);
			break;
		case MATH_TRACE_TD:
			i = TRACE_8;
			gDSO_Info.iSelected_Math_Trace = TRACE_ID_TD;
			UpdatePanel_ZoomMath(&gDSO_Info);
			break;
		default:
			return 0;
	}
	gDSO_Info.Trace[i].bTrace_ON = (state)? TRUE:FALSE;
	if (state == TRUE) 
	{
		// get a new info box
		if ((FindAvailableInfoBox(&gDSO_Info.Trace[i])) != TRUE) 
		{
			// no info box available
			gDSO_Info.Trace[i].bTrace_ON = FALSE;
			return -1;
		}
	}
	// update the trace info box
	for (i=TRACE_1; i<=TRACE_8; i++)
		UpdateInfoBox(&gDSO_Info, i);

	return 0;
}






static int sConnectStatus = 0;
int OpenNewConnection(void)
{
	int ival, error;
	char tmpStr[512];
	char addr_str[512];
	
	
	sConnectStatus = 0;
	InstallPopup(gPanel_Info.hNewConnection);

	while(!sConnectStatus)
		ProcessSystemEvents();
			
	RemovePopup(1);
	
	if (sConnectStatus < 0)
		return -1;
	
	GetCtrlVal(gPanel_Info.hNewConnection, NEWCON_CON_TYPE, &ival);
	GetCtrlVal(gPanel_Info.hNewConnection, NEWCON_ADDRESS, tmpStr);
	
	if (ival==1)//tcpip
	{
		sprintf(addr_str, "IP:%s", tmpStr);
		error = IM_MakeConnection(addr_str);
	}
	else if (ival==2)//gpib
	{
		sprintf(addr_str, "GPIB:%s", tmpStr);
		error = IM_MakeConnection(addr_str);
	}
	else
		return -1;
	
	if (!error)
		sprintf(tmpStr, "Remote LSA - %s", addr_str);
	else
		sprintf(tmpStr, "Remote LSA - %s", "No Connection established");
	
	SetPanelAttribute (gPanel_Info.hMainPanel, ATTR_TITLE, tmpStr);
	
	return error;
}


int CVICALLBACK NewConn_CB (int panel, int control, int event, void *callbackData, int eventData1, int eventData2)
{
	
	switch (event) 
	{
		case EVENT_COMMIT:
			switch (control)
			{
				case NEWCON_OK:
					sConnectStatus = 1;
					break;
				case NEWCON_CANCEL:
					sConnectStatus = -1;
					break;
				case NEWCON_ADDRESS:
					sConnectStatus = 1;
					break;
			}
		break;
	}
	return 0;
}
